
#include <stdio.h>
#include <Windows.h>
#include <string.h>
#include <stdlib.h>

//SDK interface definitions.
typedef long (__stdcall *_FapCreatePDF)(char *filename);
typedef void (__stdcall *_FapClosePDF)(long id);
typedef long (__stdcall *_FapSetPDFSecurity)(long id,long level,long limit,char *userpassword,char *ownerpassword);
typedef long (__stdcall *_FapSetPDFInfo)(long id,char *title,char *subject,char *author,char *keyword,char *creator);
typedef long (__stdcall *_FapAddPS)(long id,char *filename);
typedef long (__stdcall *_FapConvert)(long id);

//document permissions
const PERMISSION_PRINT = 1;
const PERMISSION_COPY = 2;
const PERMISSION_MODIFY = 4;

//Encryption Level
const RC4_40BITS = 40;
const RC4_128BITS = 128;

BOOL LoadDLL();
BOOL FreeDLL();
HMODULE				m_hDll=NULL;
_FapCreatePDF  apCreatePDF;
_FapClosePDF   apClosePDF;
_FapAddPS      apAddPS;
_FapConvert    apConvert;
_FapSetPDFInfo apSetPDFInfo;
_FapSetPDFSecurity apSetPDFSecurity;


//Load dynamic link library "ps2pdf.dll"!
BOOL LoadDLL()
{
	char sDllFile[]="ps2pdf.dll";

	m_hDll = LoadLibrary(sDllFile);
	if( m_hDll == NULL ) return FALSE;

	apCreatePDF=(_FapCreatePDF)GetProcAddress(m_hDll,"_CreatePDF@4");
	if(apCreatePDF==NULL) goto ERR_FLAG;

	apClosePDF=(_FapClosePDF)GetProcAddress(m_hDll,"_ClosePDF@4");
	if(apClosePDF==NULL) goto ERR_FLAG;

	apSetPDFSecurity=(_FapSetPDFSecurity)GetProcAddress(m_hDll,"_SetPDFSecurity@20");
	if(apSetPDFSecurity==NULL) goto ERR_FLAG;

	apSetPDFInfo=(_FapSetPDFInfo)GetProcAddress(m_hDll,"_SetPDFInfo@24");
	if(apSetPDFInfo==NULL) goto ERR_FLAG;

	apAddPS=(_FapAddPS)GetProcAddress(m_hDll,"_AddPS@8");
	if(apAddPS==NULL) goto ERR_FLAG;

	apConvert=(_FapConvert)GetProcAddress(m_hDll,"_Convert@4");
	if(apConvert==NULL) goto ERR_FLAG;

	return TRUE;

ERR_FLAG:
	FreeDLL(); 
	return FALSE;
}

//Free dynamic link library "ps2pdf.dll"!
BOOL FreeDLL()
{
	if( m_hDll ){
        FreeLibrary(m_hDll);
        m_hDll = NULL;
		apCreatePDF = NULL;
		apClosePDF = NULL;
		apSetPDFSecurity = NULL;
		apSetPDFInfo = NULL;
		apSetPDFInfo = NULL;
		apAddPS = NULL;
		apConvert = NULL;
	}
	return TRUE;
}

//Converting several ps/eps files to one pdf file.
void main()
{
	long id = NULL;
	long iPermission = 0;
	char sUserPw[] = "user";
	char sOwnerPw[] = "owner";

	// Load dynamic link library "ps2pdf.dll"!
	if( !LoadDLL() ) return;

	if( id = apCreatePDF("test_mm.pdf") ){
        //setting pdf header information
        apSetPDFInfo(id, "title", "subject", "author", "keywords", "createor");

        //setting pdf security
        iPermission = PERMISSION_PRINT | PERMISSION_COPY | PERMISSION_MODIFY;
        apSetPDFSecurity(id, RC4_128BITS, iPermission, sUserPw, sOwnerPw);

        //add PS/EPS files
        apAddPS(id, "./ps_files/test1.ps");
        apAddPS(id, "./ps_files/test2.ps");
        apAddPS(id, "./ps_files/test3.ps");

        //starting convet
        apConvert(id);
        
        //close pdf file
        apClosePDF(id);
	}

	// Free dynamic link library "ps2pdf.dll"!
	FreeDLL();
}